@@ -1,7 +1,8 @@
+{-# LANGUAGE PackageImports #-}
 -----------------------------------------------------------------------------
 -- |
 -- Module      :  Data.Generics.Product
--- Copyright   :  (C) 2019 Csongor Kiss
+-- Copyright   :  (C) 2020 Csongor Kiss
 -- License     :  BSD3
 -- Maintainer  :  Csongor Kiss <kiss.csongor.kiss@gmail.com>
 -- Stability   :  experimental
@@ -26,15 +27,13 @@ module Data.Generics.Product
   -- *Traversals
   , module Data.Generics.Product.Types
   , module Data.Generics.Product.Param
-  , module Data.Generics.Product.Constraints
   ) where
 
-import Data.Generics.Product.Any
-import Data.Generics.Product.Fields
-import Data.Generics.Product.Positions
-import Data.Generics.Product.Subtype
-import Data.Generics.Product.Typed
-import Data.Generics.Product.Types
-import Data.Generics.Product.Constraints
-import Data.Generics.Product.Param
-import Data.Generics.Product.HList
+import "this" Data.Generics.Product.Any
+import "this" Data.Generics.Product.Fields
+import "this" Data.Generics.Product.Positions
+import "this" Data.Generics.Product.Subtype
+import "this" Data.Generics.Product.Typed
+import "this" Data.Generics.Product.Types
+import "this" Data.Generics.Product.Param
+import "this" Data.Generics.Product.HList
